==> vdr-addon-tvmovie2vdr_0.1.0.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.0.orig/inc/tvinfofetch.pl <==
#!/usr/bin/perl



sub ReadExternalEPG_tvinfo
{

	our $datum,$start,$stop="";
	my $anzahl =0;
        foreach $sender (keys(%chan)) {
		if ($chan{$sender}[1] eq "2") {
			$anzahl++;
		}
	}

	$line = "";
	$channelnumber=0;
	foreach $sender (keys(%chan)) {
		doexit() if $please_exit;

		# Kanal fr tvmovie konfiguriert ?
		next if $chan{$sender}[1] != "2";
		$channelnumber++;
		$id = 1;
		my (@events);

		
		$tvinfo_sender = $chan{$sender}[3];
		for ($days=0;$days < $days2download ;$days++) {
			doexit() if $please_exit;

			$prevtime="";
			$now_string = DateCalc("today","+ $days days",\$err,0);
			$now_day = UnixDate($now_string, "%d");
			$now_month = UnixDate($now_string, "%m");
			$now_year = UnixDate($now_string, "%Y");
			$datum = UnixDate($now_string, "%Y-%m-%d");

			$download = "$http_base$loginURL$listeURL&showSenderID=$tvinfo_sender&newD=$now_day&newM=$now_month&newY=$now_year";
			$cachefile = "$downloadprefix" . "tvinfo_" . "$tvinfo_sender" . "_$now_year$now_month$now_day.html";
			print "\ntvinfo: getting channel $sender for $now_day.$now_month.$now_year (channel $channelnumber/". ($anzahl)." - day ". ($days+1) ."/$days2download)\n";
			my $html=GetContent($download,$cachefile);

			# Blanks am Anfang und am Ende einer Zeile entfernen
			foreach  (split("\n",$html)) {
				$line .= $1 if m|^\s*(.*?)\s*$|;
			}

			################################################################

			# Anfang und Ende wegwerfen
			$line =~ s|.*?<!-- output starts -->(.*?)</table>.*|$1|s;

			# kapitelbverschrift lschen
			$line =~ s|<tr><td colspan="3"><b>.*?</b></td></tr>||s;

			# platzhalter lschen
			$line =~ s|<td><img src="img/empty.gif" width="10"></td>||s;

			# Marker setzen
			$line =~ s|<td class="spalte." align="center" valign="top" colspan=".">|#uhrzeit#|sg;
			$line =~ s|<td class="spalte." valign="top">|#desc_genre#|sg;

###############################################################################################
# 
# Parsen der Sendungsbersicht fr einen Sender
#
			while ($line ne "") {
				doexit() if $please_exit;

				# Gibt es berhaupt Infos?
				last if $line =~ m|<tr><td class="spalte." colspan="5">An diesem Tag liegen uns zum gewhlten Sender noch keine Programminformationen vor.</td></tr>|g;
				last if $line =~ m|Sendeschluss|g;

				# Tabellenzeilen aufteilen in Sendung
				$line =~ s|^.*?#uhrzeit#(.*?)&nbsp;</td>#desc_genre#(.*?)</td>#desc_genre#(.*?)&nbsp;</td></tr>(.*)$|$4|s;
				($anfang,$desc,$genre) = ($1,$2,$3);
				last if $anfang eq "";

				# Minuten seit Tagesanfang merken fr Datumsberlauf
				$minutesstart = $1*60+$2 if $anfang =~ m/^(.*?):(.*?)$/;
				$start = UnixDate("$datum $anfang", "%s");

###############################################################################################
# 
# Parsen einer einzelnen Sendung
#
				our ($prefix,$link,$title,$subtitle,$htmldesc,$summary,$genre)="";
				while ($desc ne "") {
					doexit() if $please_exit;

					our $subtitletmp = "";
					# Beschreibung aufsplitten (jeweils Infos fr eine Sendung), den Rest wieder in $desc
					$desc =~ s|^(.*?)<a href="(.*?)">(.*?)</a>(.*)$|$4|s;
					($prefix,$link,$title) = ($1,$2,$3,); 
					$desc = "" unless $desc =~ m|^(.*?)<a href="(.*?)">(.*?)</a>(.*)$|s;

					$event_id = $link;
					$event_id =~ s/.*&sidnr=(.*?)&.*/$1/;

					# Dreck in $desc lschen
					$desc =~ s|^\s*(\S*)\s*$|$1|;

					# Link folgen, damit die Beschreibung geholt werden kann
					# caching
					$cachefile = "$downloadprefix" . "tvinfo_" . "$tvinfo_sender" . "_$event_id" . "_$now_year$now_month$now_day.html";
					$download = "$http_base$link";

					print "tvinfo: getting $event_id ($datum $anfang $title)\n";
					my $htmldesc=GetContent($download,$cachefile);

					ParseContenttvinfo($htmldesc,$datum,$anfang);
				} # while ($desc ne "")
				$subtitle =~s/ \* $//g;
				$subtitle =~s/^ \* //g;

				$summary = $oton . "|" . $summary if $oton ne "";
				$summary = "Genre: $genre" . "|" . $summary if $genre ne "";
				$summary =~ s/\|\*\|+$//sig;
				next if (UnixDate("today", "%s") > $stop); # ist die Sendung schon vorbei ?
				push(@events, {
					start        => $start, 
					stop         => $stop, 
					duration     => $stop-$start,
					title        => $title, 
					subtitle     => $subtitle, 
					summary      => $summary, 
					id           => $id,    
					state        => 1, # normale Sendung
					event_id     => $event_id 
				});
				$id++;
			} # while ($line ne "")
		} # for ($days=0;$days < $days2download ;$days++) 

		# EPG-Daten sortieren
		my($last) = 0;
		my(@temp);
		for(sort({ $a->{start} <=> $b->{start} } @events)) {
			doexit() if $please_exit;
			next if($last == $_->{start});
			push(@temp, $_); 
			$last = $_->{start};
		}
		$XML{$sender} = [ @temp ];
	} # foreach $sender (keys(%chan))
} # sub ReadExternalEPG

###############################################################################################
# 
# Parsen der Sendungsdetails
#
sub ParseContenttvinfo {
	my $htmldesc = shift;
	$datum = shift;
	my $anfang = shift;
	my $linedesc = "";

	# Blanks am Anfang und am Ende einer Zeile entfernen
	foreach  (split("\n",$htmldesc)) {
		$linedesc .= $1 if m|^\s*(.*?)\s*$|;
	}

	doexit() if $please_exit;

	# Uhrzeiten finden
	$genre = "";
	$genre = $1 if $linedesc =~ m|<td bgcolor="#eeeeee" class="v12">.*?, .*?, .*?,\s*(.*?)\s*</td>|sig;
	$ende  = $1 if $linedesc =~ m|<td bgcolor="#eeeeee" class="v12" align="right" valign="bottom">$anfang - (.*?)&nbsp;Uhr.*?</td>|s;

	# Untertitel finden
	($title,$subtitletmp) = ($1,$2) if $linedesc =~ m|<span class=HL.>(.*?)</span><br>(.*?)</td>|s;
	$subtitletmp =~ s|&nbsp;| |g;
    $subtitle .= $1 . " * " if $subtitletmp =~ m|^.*?<b>(.*?)</b>.*$|g;

	# weitere Filminfos (Originaltitel, Erstaustrahlung)
	$oton = $subtitletmp;
    $oton = $1 if $subtitletmp =~ m|^.*?<br>\s*(.*$)|g;
    $oton = $1 if $subtitletmp =~ m|^.*?<b>.*?</b>\s*(.*$)|g;
    $oton =~ s|^\s*<br>||sig;

	# Beschreibung finden
	# zuerst Beschreibungen ohne Bilder finden
	$summaryorig = $summary;
	$summary = $summaryorig . $1 . "|*||" if $linedesc =~ m|.*?<TABLE cellSpacing=0 cellPadding=2 width="75%" bgColor=#eeeeee border=0><TR><TD class="v12" vAlign=bottom>(.*?)</TD></TR></table>.*|si;

	# Falls es Bilder gibt, diese rausfiltern
	$summary = $summaryorig . $1 . "|*||" if $linedesc =~ m|.*?<TABLE cellSpacing=0 cellPadding=2 width="75%" bgColor=#eeeeee border=0><TR><TD class="v12" vAlign=bottom><table.*?</table>(.*?)</TD></TR></table>.*|si;

	# saubere Zeilenumbrche fr VDR und html-tags subern
	$summary =~s/.*Es liegen keine weiteren Beschreibungen zur Sendung vor.*//g;
	$summary =~s|&nbsp;||g;
	$summary =~s/<br><br>/<br>/g;
	$summary =~s/<br>/|/g;
	$summary =~s/\|$//g;
#	$summary = "Genre: $genre|$summary";

	# Datumsberlauf in der Stopzeit?
	$minutesstop = $1*60+$2 if $ende =~ m/^(.*?):(.*?)$/;
	if ($minutesstop < $minutesstart) {
		$datum = DateCalc($datum,"+ 1 day",\$err,0);
		$datum = UnixDate($datum, "%Y-%m-%d");
	}
	$stop = UnixDate("$datum $ende", "%s");
}

return 1;

==> vdr-addon-tvmovie2vdr_0.1.5.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.5.orig/inc/tvinfofetch.pl <==
#!/usr/bin/perl



sub ReadExternalEPG_tvinfo
{
	&Date_Init("Language=German","DateFormat=non-US");
	our $datum,$start,$stop="";
	my $anzahl =0;
        foreach $sender (keys(%chan)) {
		if ($chan{$sender}[1] eq "2") {
			$anzahl++;
		}
	}

	$line = "";
	$channelnumber=0;
	foreach $sender (keys(%chan)) {
		doexit() if $please_exit;

		# Kanal fr tvmovie konfiguriert ?
		next if $chan{$sender}[1] != "2";
		$channelnumber++;
		$id = 1;
		my (@events);

		
		$tvinfo_sender = $chan{$sender}[3];
		for ($days=0;$days < $days2download ;$days++) {
			doexit() if $please_exit;

			$prevtime="";
			$now_string = DateCalc("heute","+ $days tage",\$err,0);
			$now_day = UnixDate($now_string, "%d");
			$now_month = UnixDate($now_string, "%m");
			$now_year = UnixDate($now_string, "%Y");
			$datum = UnixDate($now_string, "%Y-%m-%d");

			$download = "$http_base$loginURL$listeURL&showSenderID=$tvinfo_sender&newD=$now_day&newM=$now_month&newY=$now_year";
			$cachefile = "$downloadprefix" . "tvinfo_" . "$tvinfo_sender" . "_$now_year$now_month$now_day.html";
			print "\ntvinfo: getting channel $sender for $now_day.$now_month.$now_year (channel $channelnumber/". ($anzahl)." - day ". ($days+1) ."/$days2download)\n";
			my $html=GetContent($download,$cachefile);

			# Blanks am Anfang und am Ende einer Zeile entfernen
			foreach  (split("\n",$html)) {
				$line .= $1 if m|^\s*(.*?)\s*$|;
			}

			################################################################

			# Bugfix fr fehlerhafte tvinfo-Seiten zwischen 01:00 und 06:00 Uhr
			$line =~ m|^.*?Programm auf <b>(.*?)</b>.*?$|s;
			$dbgSender=$1;
			$line =~ m|^.*?Am .*?, dem (.*?)</td>.*?$|s;
			$founddate = ParseDate("$1");	
			$datum = UnixDate($founddate, "%Y-%m-%d");

			# Anfang und Ende wegwerfen
			$line =~ s|.*?<!-- output starts -->(.*?)</table>.*|$1|s;

			# kapitelbverschrift lschen
			$line =~ s|<tr><td colspan="3"><b>.*?</b></td></tr>||s;

			# platzhalter lschen
			$line =~ s|<td><img src="img/empty.gif" width="10"></td>||s;

			# Marker setzen
			$line =~ s|<td class="spalte." align="center" valign="top" colspan=".">|#uhrzeit#|sg;
			$line =~ s|<td class="spalte." valign="top">|#desc_genre#|sg;

###############################################################################################
# 
# Parsen der Sendungsbersicht fr einen Sender
#
			while ($line ne "") {
				doexit() if $please_exit;

				# Gibt es berhaupt Infos?
				last if $line =~ m|<tr><td class="spalte." colspan="5">An diesem Tag liegen uns zum gewhlten Sender noch keine Programminformationen vor.</td></tr>|g;
				last if $line =~ m|Sendeschluss|g;

				# Tabellenzeilen aufteilen in Sendung
				$line =~ s|^.*?#uhrzeit#(.*?)&nbsp;</td>#desc_genre#(.*?)</td>#desc_genre#(.*?)&nbsp;</td></tr>(.*)$|$4|s;
				($anfang,$desc,$genre) = ($1,$2,$3);
				last if $anfang eq "";

				# Minuten seit Tagesanfang merken fr Datumsberlauf
				$minutesstart = $1*60+$2 if $anfang =~ m/^(.*?):(.*?)$/;
				$start = UnixDate("$datum $anfang", "%s");

###############################################################################################
# 
# Parsen einer einzelnen Sendung
#
				our ($prefix,$link,$title,$subtitle,$htmldesc,$summary,$genre)="";
				while ($desc ne "") {
					doexit() if $please_exit;

					our $subtitletmp = "";
					# Beschreibung aufsplitten (jeweils Infos fr eine Sendung), den Rest wieder in $desc
					$desc =~ s|^(.*?)<a href="(.*?)">(.*?)</a>(.*)$|$4|s;
					($prefix,$link,$title) = ($1,$2,$3,); 
					$desc = "" unless $desc =~ m|^(.*?)<a href="(.*?)">(.*?)</a>(.*)$|s;

					$event_id = $link;
					$event_id =~ s/.*&sidnr=(.*?)&.*/$1/;

					# Dreck in $desc lschen
					$desc =~ s|^\s*(\S*)\s*$|$1|;

					# Link folgen, damit die Beschreibung geholt werden kann
					# caching
					$cachefile = "$downloadprefix" . "tvinfo_" . "$tvinfo_sender" . "_$event_id" . "_$now_year$now_month$now_day.html";
					$download = "$http_base$link";

					print "tvinfo: getting $dbgSender $event_id ($datum $anfang $title)\n";
					my $htmldesc=GetContent($download,$cachefile);

					ParseContenttvinfo($htmldesc,$datum,$anfang);
				} # while ($desc ne "")
				$subtitle =~s/ \* $//g;
				$subtitle =~s/^ \* //g;

				$summary = $oton . "|" . $summary if $oton ne "";
				$summary = "Genre: $genre" . "|" . $summary if $genre ne "";
				$summary =~ s/\|\*\|+$//sig;
				next if (UnixDate("heute", "%s") > $stop); # ist die Sendung schon vorbei ?
				push(@events, {
					start        => $start, 
					stop         => $stop, 
					duration     => $stop-$start,
					title        => $title, 
					subtitle     => $subtitle, 
					summary      => $summary, 
					id           => $id,    
					state        => 1, # normale Sendung
					event_id     => $event_id 
				});
				$id++;
			} # while ($line ne "")
		} # for ($days=0;$days < $days2download ;$days++) 

		# EPG-Daten sortieren
		my($last) = 0;
		my(@temp);
		for(sort({ $a->{start} <=> $b->{start} } @events)) {
			doexit() if $please_exit;
			next if($last == $_->{start});
			push(@temp, $_); 
			$last = $_->{start};
		}
		$XML{$sender} = [ @temp ];
	} # foreach $sender (keys(%chan))
} # sub ReadExternalEPG

###############################################################################################
# 
# Parsen der Sendungsdetails
#
sub ParseContenttvinfo {
	my $htmldesc = shift;
	$datum = shift;
	my $anfang = shift;
	my $linedesc = "";

	# Blanks am Anfang und am Ende einer Zeile entfernen
	foreach  (split("\n",$htmldesc)) {
		$linedesc .= $1 if m|^\s*(.*?)\s*$|;
	}

	$linedesc = decode_entities($linedesc);

	doexit() if $please_exit;

	# Uhrzeiten finden
	$genre = "";
	$genre = $1 if $linedesc =~ m|<td bgcolor="#eeeeee" class="v12">.*?, .*?, .*?,\s*(.*?)\s*</td>|sig;
	$ende  = $1 if $linedesc =~ m|<td bgcolor="#eeeeee" class="v12" align="right" valign="bottom">$anfang - (.*?)&nbsp;Uhr.*?</td>|s;

#        <tr>
#            <td class="v12" colspan="2" align="center">
#              <span class=HL1>Der Bulle von Tlz</span><br><b> In guten Hnden</b> DEU&nbsp;2004            </td>
#        </tr>


	# Untertitel finden
	($title,$subtitletmp) = ($1,$2) if $linedesc =~ m|<span class=HL.>(.*?)</span><br>(.*?)</td>|s;
	$subtitletmp =~ s|&nbsp;| |g;

	$subtitletmp =~ s|<b>\s*||g;
	$subtitletmp =~ s|</b>\s*| |g;
	$subtitletmp =~ s|\s*$||g;

	$subtitle = $subtitletmp . " * ";

	# weitere Filminfos (Originaltitel, Erstaustrahlung)
	$oton = $subtitletmp;
	$oton = $1 if $subtitletmp =~ m|^.*?<br>\s*(.*$)|g;
	$oton = $1 if $subtitletmp =~ m|^.*?<b>.*?</b>\s*(.*$)|g;
	$oton =~ s|^\s*<br>||sig;

	# Beschreibung finden
	# zuerst Beschreibungen ohne Bilder finden
	$summaryorig = $summary;
	$summary = $summaryorig . $1 . "|*||" if $linedesc =~ m|.*?<TABLE cellSpacing=0 cellPadding=2 width="75%" bgColor=#eeeeee border=0><TR><TD class="v12" vAlign=bottom>(.*?)</TD></TR></table>.*|si;

	# Falls es Bilder gibt, diese rausfiltern
	$summary = $summaryorig . $1 . "|*||" if $linedesc =~ m|.*?<TABLE cellSpacing=0 cellPadding=2 width="75%" bgColor=#eeeeee border=0><TR><TD class="v12" vAlign=bottom><table.*?</table>(.*?)</TD></TR></table>.*|si;

	$darsteller = $1 if $linedesc =~ m|.*<tr><td class="v12" valign="top">Schauspieler:</td><td class="v12" valign="top" width=80%>(.*?)</td></tr>.*|si;

	$subtitle =~ s/<br>/|/g;
#print "subtitle: $subtitle\n\n";
	$summary = $subtitle . "|" . $summary . $darsteller;

	# saubere Zeilenumbrche fr VDR und html-tags subern
	$summary =~s/.*Es liegen keine weiteren Beschreibungen zur Sendung vor.*//g;
	$summary =~s|&nbsp;||g;
	$summary =~s/<br><br>/<br>/g;
	$summary =~s/<br>/|/g;
	$summary =~s/\|$//g;
#	$summary = "Genre: $genre|$summary";

	# Datumsberlauf in der Stopzeit?
	$minutesstop = $1*60+$2 if $ende =~ m/^(.*?):(.*?)$/;
	if ($minutesstop < $minutesstart) {
		$datum = DateCalc($datum,"+ 1 tag",\$err,0);
		$datum = UnixDate($datum, "%Y-%m-%d");
	}
	$stop = UnixDate("$datum $ende", "%s");
}

return 1;
